summaryrefslogtreecommitdiffstats
path: root/lib/kformula/spaceelement.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kformula/spaceelement.h')
-rw-r--r--lib/kformula/spaceelement.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/lib/kformula/spaceelement.h b/lib/kformula/spaceelement.h
index 0f5db35d..856af25e 100644
--- a/lib/kformula/spaceelement.h
+++ b/lib/kformula/spaceelement.h
@@ -78,7 +78,7 @@ public:
/**
* Calculates our width and height and
- * our tqchildren's tqparentPosition.
+ * our tqchildren's parentPosition.
*/
virtual void calcSizes( const ContextStyle& cstyle,
ContextStyle::TextStyle tstyle,
@@ -87,15 +87,15 @@ public:
/**
* Draws the whole element including its tqchildren.
* The `tqparentOrigin' is the point this element's tqparent starts.
* We can use our tqparentPosition to get our own origin then.
*/
virtual void draw( TQPainter& painter, const LuPixelRect& r,
const ContextStyle& context,
ContextStyle::TextStyle tstyle,
ContextStyle::IndexStyle istyle,
StyleAttributes& style,
- const LuPixelPoint& tqparentOrigin );
+ const LuPixelPoint& parentOrigin );
/**
* Moves the cursor away from the given child. The cursor is
@@ -87,15 +87,15 @@ public:
/**
* Draws the whole element including its tqchildren.
- * The `tqparentOrigin' is the point this element's tqparent starts.
- * We can use our tqparentPosition to get our own origin then.
+ * The `parentOrigin' is the point this element's tqparent starts.
+ * We can use our parentPosition to get our own origin then.
*/
virtual void draw( TQPainter& painter, const LuPixelRect& r,